Alternate test attribute that allows dependencies between tests.

This crate is intended to support situations where one test is used as
another test's setup. For example:

```rust
use testdep::testdep;

/// This is a normal test, but it returns a `User` object.
#[testdep]
fn log_in() -> User {
    todo!()
}

/// This test will run after `log_in`, and take its result by reference.
#[testdep]
fn publish_crate(log_in: &User) -> Crate {
    todo!()
}

/// This test will run after `log_in` and `publish_crate`.
#[testdep]
fn yank_crate(log_in: &User, publish_crate: Crate) {
    todo!()
}
```

When a test returns an object, it will be stored globally after the
test succeeds. When a test takes an argument, the test with a name
matching the argument will be run first (even if it has been filtered
out). Its result can be accessed by reference or by value.

At the end of the test run, any objects that were produced by a test
will be dropped before the process exits.

Be careful about creating cycles in test dependencies. They will
deadlock the test runner.
